# Licensed under the MIT License
# https://github.com/craigahobbs/schema-markdown/blob/main/LICENSE

"""
The Schema Markdown compiler and schema validation tool main entry point
"""

from .main import main


if __name__ == '__main__': # pragma: no cover
    main()
